.. _spkg_jsonpointer:

jsonpointer: Identify specific nodes in a JSON document (RFC 6901)
==================================================================

Description
-----------

Identify specific nodes in a JSON document (RFC 6901)

License
-------

Modified BSD License

Upstream Contact
----------------

https://pypi.org/project/jsonpointer/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.4

version_requirements.txt::

    jsonpointer

Equivalent System Packages
--------------------------

(none known)
